==> curlpp-0.3.1_1.tbz: share/examples/curlpp/example11.cpp <==
#include <iostream> 
/*
 *    Copyright (c) <2002-2003> <Jean-Philippe Barrette-LaPierre>
 *    
 *    Permission is hereby granted, free of charge, to any person obtaining
 *    a copy of this software and associated documentation files 
 *    (curlpp), to deal in the Software without restriction, 
 *    including without limitation the rights to use, copy, modify, merge,
 *    publish, distribute, sublicense, and/or sell copies of the Software,
 *    and to permit persons to whom the Software is furnished to do so, 
 *    subject to the following conditions:
 *    
 *    The above copyright notice and this permission notice shall be included
 *    in all copies or substantial portions of the Software.
 *    
 *    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
 *    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
 *    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
 *    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 *    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#include <iostream>

#include "../src/curlpp.hpp"

#define HTTP_URL "http://www.slashdot.org/"

#define INTERFACE1 "eth0"

int main()
{
   try
   {
      curlpp::cleanup cleaner;
      
      curlpp::easy request1;
      request1.url( HTTP_URL );
      request1.verbose();
      
      request1.interface( INTERFACE1 );
      
      std::cout << "performing with the INTERFACE1 interface" << std::endl;
      request1.perform();
   }
   catch ( curlpp::exception & e )
   {
      std::cout << e.what() << std::endl;
   }
}

==> curlpp-0.3.3.tbz: share/examples/curlpp/example11.cpp <==
#include <iostream> 
/*
 *    Copyright (c) <2002-2005> <Jean-Philippe Barrette-LaPierre>
 *    
 *    Permission is hereby granted, free of charge, to any person obtaining
 *    a copy of this software and associated documentation files 
 *    (curlpp), to deal in the Software without restriction, 
 *    including without limitation the rights to use, copy, modify, merge,
 *    publish, distribute, sublicense, and/or sell copies of the Software,
 *    and to permit persons to whom the Software is furnished to do so, 
 *    subject to the following conditions:
 *    
 *    The above copyright notice and this permission notice shall be included
 *    in all copies or substantial portions of the Software.
 *    
 *    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
 *    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
 *    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
 *    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 *    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#include <iostream>

#include <curlpp/curlpp.hpp>

#define HTTP_URL "http://example.com"

int main(int argc, char **argv)
{
  if(argc != 2) {
    std::cerr << "example11: Wrong number of argument." << std::endl;
    std::cerr << "example11: Usage: example11 interface" << std::endl;

    return EXIT_FAILURE;
  }

  try {
    curlpp::cleanup cleaner;
      
    curlpp::easy request1;
    request1.url(HTTP_URL);
    request1.verbose();
      
    request1.network_interface(argv[1]);
      
    std::cout << "performing with the given interface" << std::endl;
    request1.perform();
  }
  catch (curlpp::exception & e) {
    std::cout << e.what() << std::endl;
  }
}
